clear all
set mem 500m
set matsize 800
set more 1

****************************
*
* RECODE STANDARD (SECRET BALLOT) SURVEY VARIABLES
*
****************************
use "..\Not in Replication Archive Source Files\yale0015_output.dta", clear
//include "01_Sub_DoRecodes.do"

****************************
*
* DEMOGRAPHICS
*
****************************
** state
tab v206, gen(state_)
* drop CA indicator
drop state_5
**Race
tab  v211, gen(race)
gen r_white=race1
gen r_black=race2
gen r_hispanic=race3
gen r_otherrace=race4+race5+race6+race7+race8
label var r_white "Race: White (1=yes)"
label var r_black "Race: Black (1=yes)"
label var r_hispanic "Race: Hispanic (1=yes)"
label var r_otherrace "Race: Other Race (1=yes)"

**Gender
gen gender=v208-1
label var gender "Female (1=yes)"

**Age
gen age=2010-v207
gen age2=(age^2)/100
label var age "Age (Years)"
label var age2 "Age-squared/100"

**Family Income
gen income=v246
replace income=15 if income>15
gen incomemis = (income>14)
label var incomemis "Income Missing"
label var income "Income (1=<10k; 14=>150k; 15=RF/Skipped)"

**Education
gen educ=v213
label var educ "Education (1=No HS; 6=Post-grad)"

****************************
*
* POLITICAL PREFERENCES
*
****************************
**PID / Strength of PID
recode v212 (1=3) (2=2) (3=1) (4 8=0) (5=-1) (6=-2) (7=-3) (*=.), gen(pid7)
label var pid7 "Party ID (-3=Str. Rep.; 3=Str. Dem.)"

gen pidstr7=abs(pid7)
label var pidstr7 "Strength PID (0=Indep/not sure, 3=Str. ID)"

**Ideology / Strength of ideology
recode v243 (5=-2) (4=-1) (3 6=0) (2=1) (1=2) (*=.), gen(ideol)
label var ideol "Ideology (-2=very cons.; 0=moderate/not sure; +2=very lib.)"

gen ideolstr=abs(ideol)
label var ideolstr "Str. Ideology (0=moderate/not sure; +2=str. ideol)"

**** STRENGTH OF PREFERENCES INDEX
alpha pidstr7 ideolstr, std gen(strprefs)

****************************
*
* POLITICAL RESOURCES
*
****************************
**Interest in Politics
recode v244 (1=4) (2=3) (3=2) (4 5 6=1) (*=.), gen(painterest)
label var painterest "Interest in News & Public Affairs (1-4) [DK/Skipped/Hardly at all=1]"
egen intSTDpa=std(painterest)

sort v206
merge v206 using "..\Not in Replication Archive Source Files\state_leg.dta"
gen pk1=(cc309a==2)
gen pk2=(cc309b==2)
gen pk3=(cc309c==state_senate)
gen pk4=(cc309d==state_house)

gen raw_pknow=pk1+pk2+pk3+pk4
drop state_senate state_house


****************************
*
* AGREEMENT IN SOCIAL NETWORK
*
*****************************
foreach i in yal150 yal151 yal152 yal153 yal154 yal155 yal156 {
gen `i'_dk=(`i'==8)
}
forvalues i=150/156{
recode yal`i' (1=5) (2=4) (8 3=3) (4=2) (5=1) (*=.)
}

**********************
*
* RECODE MISSING ON SOCIAL KNOWLEDGE OF CHOICES ITEMS TO MISSING
*
**********************
recode yal160 yal161 yal162 yal163 (1=1) (2=2) (3=3) (*=.)

**********************
*
* RECODE MISSING ON RULER ITEMS TO MISSING
*
**********************
recode yal070 yal071 yal072 yal073 (101/.=.)

****************************
*
* OUTCOME VARIABLES
*
*****************************
* Vote Choices Should Be Discussed or Kept Private? (SCORED SO THAT HIGHER VALUES INDICATE "BETTER" TO DISCUSS)
recode yal130 (1=0) (2=1) (*=.), gen(treat_ch_private)
recode yal131 (1=2) (2=1) (3=0) (4=-1) (5=-2) (*=.), gen(discuss_for_info)
recode yal132 (1=-2) (2=-1) (3=0) (4=1) (5=2) (*=.), gen(discuss_bad_pressure)
replace discuss_for_info=(discuss_for_info+2)/4
replace discuss_bad_pressure=(discuss_bad_pressure+2)/4
label var treat_ch_private "Best to discuss vote choices with others = 1"
label var discuss_for_info "Discuss for information? (0=strongly disagree; 1=strongly agree)"
label var discuss_bad_pressure "Discuss bad because of pressure? (0=strongly agree; 1=strongly disagree)"

****************************
*
* SET SAMPLE
*
****************************
reg treat_ch_private discuss_for_info discuss_bad_pressure yal070 yal071 yal072 yal073 raw_pknow painterest r_black r_hispanic r_otherrace educ income incomemis gender age age2 strprefs yal150 yal151 yal160 yal161 yal162 yal163 state* [aw=weight], r
keep if e(sample)

****************************
*
* STANDARDIZE VARIABLES WITHIN SAMPLE
*
****************************
* Strength of Political Preferences
sum strprefs
replace strprefs=(strprefs-r(mean))/r(sd)
label var strprefs "Strength of Preferences (Ideology and PID, Mean=0, SD=1)"

* Social Network Agreement 
egen agree_family=std(yal150)
egen agree_friends=std(yal151)
gen agree_family_dk=yal150_dk
gen agree_friends_dk=yal151_dk
replace agree_family=0 if agree_family_dk==1
replace agree_friends=0 if agree_friends_dk==1
label var agree_family "Agree with Family (Mean=0, SD=1)"
label var agree_friends "Agree with Friends and Neighbors (Mean=0, SD=1)"
label var agree_family_dk "Don't Know if Agree with Family (DK=1, esle==0)"
label var agree_friends_dk "Don't Know if Agree with Friends and Neighbors (DK=1, else=0)"

local social="agree_family agree_friends agree_family_dk agree_friends_dk"

* Political Resources and Possible Confounds
egen pers_trust=std(yal070)
egen gov_trust=std(yal071)
egen ext_efficacy=std(yal072)
egen int_efficacy=std(yal073)
label var pers_trust "Interpersonal Trust (Mean=0, SD=1)"
label var gov_trust "Trust in Government (Mean=0, SD=1)"
label var ext_efficacy "External Efficacy (Mean=0, SD=1)"
label var int_efficacy "Internal Efficacy (Mean=0, SD=1)"

egen interest=std(painterest)
label var interest "Political Interest (Mean=0, SD=1)"

egen pknow=std(raw_pknow)
label var pknow "Political Knowledge (Mean=0, SD=1)"

alpha int_efficacy pkno interest, std gen(capable)
sum capable
replace capable=(capable-r(mean))/r(sd)
label var capable "Political Resources Index (Mean=0, SD=1)"

* Capable (i.e., Politial Resources Index) x Agreement
gen familyXcapable=capable*agree_family
gen friendsXcapable=capable*agree_friends
gen familydkXcapable=capable*agree_family_dk
gen friendsdkXcapable=capable*agree_friends_dk
label var familyXcapable "Family Agreement X Political Resources"
label var friendsXcapable "Friends Agreement X Political Resources"
label var familydkXcapable "DK Family Agreement X Political Resources"
label var friendsdkXcapable "DK Friends Agreement X Political Resources"

* Str PRefs  x Agreement
gen familyXstrpref=strprefs*agree_family
gen friendsXstrpref=strprefs*agree_friends
gen familydkXstrpref=strprefs*agree_family_dk
gen friendsdkXstrpref=strprefs*agree_friends_dk
label var familyXstrpref "Family Agreement X Strength of Preferences"
label var friendsXstrpref "Friends Agreement X Strength of Preferences"
label var familydkXstrpref "DK Family Agreement X Strength of Preferences"
label var friendsdkXstrpref "DK Friends Agreement X Strength of Preferences"

#delimit ;
keep weight r_black r_hispanic r_otherrace educ income incomemis gender age age2 yal130 yal131 yal132 yal070 yal071 yal072 yal073 raw_pknow painterest strprefs yal150 yal151 yal160 yal161 yal162 yal163 state* 
int_efficacy strpref agree_family agree_friends pers_trust gov_trust ext_efficacy interest pknow 
treat_ch_private discuss_for_info discuss_bad_press agree_family_dk agree_friends_dk capable *Xstrpref *Xcapable
;
#delimit cr

save POQ_PublicReplicationDatafile.dta, replace
